@@ -7,6 +7,7 @@ import itertools
 import warnings
 import numpy as np
 from numpy.lib.recfunctions import rename_fields as np_rename_fields
+from numpy.lib.recfunctions import append_fields as np_append_fields
 from scipy.interpolate import griddata
 from shapely import wkt
 from shapely.geometry import Point, Polygon, MultiPoint, MultiPolygon, LineString, MultiLineString, LinearRing, box, mapping, shape
@@ -57,6 +58,7 @@ from lfmaptools.utilities import (_nice_round,
                                   _decompress_gz)
 from lfmaptools.netcdf_utils import nc2np, nc_max, nc_min, nc_min_max
 from lfmaptools.geotools import EastingNorthing_TM, LatLon_TM_polygonize, LatLon_TM
+from lfmaptools.demtools import load_dem, load_hillshade
 from lfmaptools.epsg_defs import webmerc, wgs84
 from lfmaptools.mapping import add_stamen_basemap
 from lfmaptools.interptools import interp_weights, interpolate
@@ -265,8 +267,7 @@ class LaharFlowData(object):
             self.get_nc_files()
             self.get_tar_files()
             self.get_gz_files()
-            if not self.zipped:
-                self.get_tiff_files()
+            self.get_tiff_files()
 
             self.clatlong = [self.clat,self.clong]
 
@@ -540,6 +541,9 @@ class LaharFlowData(object):
 
         return (lat_res, lon_res)
 
+    def EN_from_latlon(self, lat, lon):
+        return np.array(EastingNorthing_TM(self.clatlong, (lat,lon)))
+
     def get_XY(self):
 
         x = ((np.arange(0,self.xSize,self.dX)-self.xSize/2)+self.dX/2)
@@ -570,6 +574,10 @@ class LaharFlowData(object):
         self.txt_files = [f for f in self.files if f.endswith('.txt')]
         self.txt_files.sort()
 
+    def get_tiff_files(self):
+        self.tiff_files = [f for f in self.files if f.endswith('.tif') or f.endswith('.tiff')]
+        self.tiff_files.sort()
+
     def _snapshot_txt_files(self):
         txt_files = [f for f in self.txt_files if f.strip('.txt').isnumeric()]
         txt_files.sort()
@@ -587,19 +595,6 @@ class LaharFlowData(object):
         sfiles.sort()
         return sfiles
 
-    def get_tiff_files(self):
-        self.tiffFiles = {}
-        k=0
-        for f in self.files:
-            if f.endswith('.tif'):
-                raster = rio.open(os.path.join(self.dir,f))
-                epsg = raster.crs.to_epsg()
-                raster.close()
-                this_file = {'file': f,'epsg':epsg,'index':k}
-                self.tiffFiles[str(f)] = this_file
-                k+=1
-        return
-
     def _update_tiff_files(self,file,epsg=None):
         assert(file.endswith('tif')), 'In updateTiff, file must have a .tif extension; received {}'.format(file)
 
@@ -793,6 +788,10 @@ class LaharFlowData(object):
         else:
             data_cols = [x for x in var]
 
+        if filetype=='snapshot' and 'concentration' in data_cols:
+            conc = np.divide(data['mass_of_solids'], data['mass_per_unit_area'], where=data['mass_per_unit_area']>1e-6)
+            data = np_append_fields(data, 'concentration', conc, dtypes=np.float64)
+
         if res is None:
             res_lat, res_lon = self._get_latlon_res()
         else:
@@ -958,15 +957,6 @@ class LaharFlowData(object):
         #     ds[col].attrs["units"] = fmt['units']
         #     ds[col].attrs["symbol"] = fmt['symbol']
 
-        # if filetype=='snapshot' and 'concentration' not in data_cols:
-        #     ds['concentration'] = ds['mass_of_solids']
-        #     ds['concentration'] = np.divide(ds['mass_of_solids'], ds['mass_per_unit_area'], where=ds['mass_per_unit_area'].where(ds['mass_per_unit_area'].data>1e-8))
-        #     fmt = _get_LF_output_fmt('concentration')
-        #     ds['concentration'].attrs["short_name"] = fmt['short_name']
-        #     ds['concentration'].attrs["long_name"] = fmt['long_name']
-        #     ds['concentration'].attrs["units"] = fmt['units']
-        #     ds['concentration'].attrs["symbol"] = fmt['symbol']
-
         # return raster
 
     def _raster_flatten(self, raster, var):
@@ -1409,7 +1399,7 @@ class LaharFlowData(object):
 
         if filename is not None:
             data = self._get_data(filename)
-        POI_xy = np.array(EastingNorthing_TM(self.clatlong, (lat, lon)))*1e3
+        POI_xy = self.EN_from_latlon(lat, lon)*1e3
 
         if self.xy_in_data_extent(data, POI_xy):
 
